@@ -3,8 +3,8 @@ from io import BytesIO as IO
 from unittest import mock
 from datetime import datetime, timedelta
 
-from shellyhtcollector.Server import InterceptorHandlerFactory
-from shellyhtcollector.Database import MeasurementDatabase
+from htcollector.Server import InterceptorHandlerFactory
+from htcollector.Database import MeasurementDatabase, Measurement
 
 
 @pytest.fixture(scope="class")
@@ -162,3 +162,60 @@ class TestInterceptor:
                         r = database.retrieveMeasurements(stationid, start)
                         print(start, r)
                         assert len(r) == 0
+
+    def test_GET_GRAPH(self, database, capsys):
+        stationid = "graphid-123456"
+        interceptorhandler = InterceptorHandlerFactory.getHandler(database)
+
+        database.names(
+            stationid, "testroom1"
+        )  # without a stationid mapping we never get anything back
+        start = datetime.now()
+        database.storeMeasurement(Measurement(stationid, 10, 40))
+        with mock.patch.object(interceptorhandler, "finish", finish):
+            with mock.patch.object(
+                interceptorhandler, "date_time_string", date_time_string
+            ):
+                with mock.patch.object(
+                    interceptorhandler, "version_string", version_string
+                ):
+                    with mock.patch.object(interceptorhandler, "wbufsize", lambda: 1):
+                        start = datetime.now()
+                        request = MockRequest(
+                            b"/graph?id=%s" % bytes(stationid, "UTF-8")
+                        )
+                        ihinstance = interceptorhandler(
+                            request, ("127.0.0.1", 12345), "testserver.example.org"
+                        )
+                        captured = capsys.readouterr()
+                        print(captured.out)
+                        assert ihinstance.wfile.getvalue()[:15] == b"HTTP/1.0 200 OK"
+
+    def test_GET_HTML(self, database, capsys):
+        stationid = "htmlid-123456"
+        interceptorhandler = InterceptorHandlerFactory.getHandler(database)
+
+        database.names(
+            stationid, "htmlroom1"
+        )  # without a stationid mapping we never get anything back
+        start = datetime.now()
+        database.storeMeasurement(Measurement(stationid, 10, 40))
+        with mock.patch.object(interceptorhandler, "finish", finish):
+            with mock.patch.object(
+                interceptorhandler, "date_time_string", date_time_string
+            ):
+                with mock.patch.object(
+                    interceptorhandler, "version_string", version_string
+                ):
+                    with mock.patch.object(interceptorhandler, "wbufsize", lambda: 1):
+                        start = datetime.now()
+                        request = MockRequest(
+                            b"/html?id=%s" % bytes(stationid, "UTF-8")
+                        )
+                        ihinstance = interceptorhandler(
+                            request, ("127.0.0.1", 12345), "testserver.example.org"
+                        )
+                        captured = capsys.readouterr()
+                        print(captured.out)
+                        assert ihinstance.wfile.getvalue()[:15] == b"HTTP/1.0 200 OK"
+
